@@ -195,7 +195,7 @@ def mcmc(args):
                          minAfactor=args.minAfactor, maxArchange=args.maxArchange, burnAfactor=args.burnAfactor,
                          burnGR=args.burnGR, maxGR=args.maxGR, minTz=args.minTz, minsteps=args.minsteps,
                          minpercent=args.minpercent, thin=args.thin, serial=args.serial, save=args.save,
-                         savename=backend_loc, proceed=args.proceed, proceedname=backend_loc)
+                         savename=backend_loc, proceed=args.proceed, proceedname=backend_loc, headless=args.headless)
 
     mintz = statevars.mintz
     maxgr = statevars.maxgr
